<?php
/**
 * Eve-Online API Trawler
 *
 */

class AssetsListAPI
{
	function AssetsListAPI( $userID, $apiKey, $charID, $corpID = 0 )
    {
		$this->userID_ = $userID;
		$this->charID_ = $charID;
		$this->apiKey_ = $apiKey;
		$this->corpID_ = $corpID;
		
		$this->apiString_ = array( "userID" => $this->userID_, "apiKey" => $this->apiKey_, "characterID" => $this->charID_ );
		
		if ($this->corpID_ != 0)
		{
			$this->CacheTime_ = ApiCache::get($this->corpID_ . "_corpassetlist");
			$this->CurrentTime_ = ApiCurrent::get($this->corpID_ . "_corpassetlist");
		} else {
			$this->CacheTime_ = ApiCache::get($this->charID_ . "_assetlist");
			$this->CurrentTime_ = ApiCurrent::get($this->charID_ . "_assetlist");
		}
	}
	
	function fetch()
	{
		if ($this->corpID_ != 0)
		{
			$baseURL = "http://api.eve-online.com/corp/AssetList.xml.aspx?";
			$fname = "cache/" . $this->corpID_ . "_corpassetlist.xml";
		} else{
			$baseURL = "http://api.eve-online.com/char/AssetList.xml.aspx?";
			$fname = "cache/" . $this->charID_ . "_assetlist.xml";
		}

		if ($this->CacheTime_ == "")
    	{
        	$this->CacheTime_ = "2005-01-01 00:00:00"; // fake date to ensure that it runs first time.
    	}
		
		if (is_file(getcwd()."/".$fname))
			$cacheexists = true;
		else
			$cacheexists = false;
		
		if ((strtotime(gmdate("M d Y H:i:s")) - strtotime($this->CacheTime_) > 0) || !$cacheexists )
        {
            // Load new XML
			$xmlString = @file_get_contents( $baseURL . http_build_query( $this->apiString_ ) );
			$this->isCached = false;
			
			if(!isset($xmlString) || $xmlString === false)
				$this->error_ = "API Website not responding.";
		} else {
			// load cached XML
			$xmlString = @file_get_contents( $fname );
			$this->isCached = true;
		}
        $xml = simplexml_load_string( $xmlString );
        
		if( isset($xml->error) )
        {
			$this->error_ = $xml->error;
            $xml = @simplexml_load_file( $fname );
			$this->isCached = true;
        } else {
            file_put_contents( $fname, $xmlString );
        }
		
		// Set Cached Time
		if ($xml->cachedUntil)
		{
			$this->CacheTime_ = $xml->cachedUntil;
			$this->CurrentTime_ = $xml->currentTime;
			
			if ($this->corpID_ != 0)
			{
				ApiCache::set($this->corpID_ . "_corpassetlist", $this->CacheTime_);
    			ApiCurrent::set($this->corpID_ . "_corpassetlist", $this->CurrentTime_);
			} else {
				ApiCache::set($this->charID_ . "_assetlist", $this->CacheTime_);
				ApiCurrent::set($this->charID_ . "_assetlist", $this->CurrentTime_);
			}
		}
		
		if ($this->isCached)
		{
			$this->output_ = "using cached file from: " . $this->CurrentTime_ . " and is cached until: " . $this->CacheTime_;
		} else {
			$this->output_ = "received new XML at: " . $this->CurrentTime_;
		}
		
		if( !$xml->result->rowset->row )
			return false;
			
		// collect data from rows
		// by calling a function we allow it to call itself if needed - allows us to parse nested containers ad infinitum
		$this->item($xml->result->rowset, 0, 0);

		return;
	}
	
	function item($rowset, $container, $locationid)
	{
		foreach($rowset->row as $row)
		{	
			if ($row['locationID'] != 0)
				$locationid = $row['locationID'];
			$item['container'] = $container;
			$item['itemID'] = $row['itemID'];
			
			// use following formula to correct locationID as per http://www.eveonline.com/ingameboard.asp?a=topic&threadID=667487
			if  ( ($locationid >= 66000000) && ($locationid < 67000000) )
				$newlocid = $locationid - 6000001;
			elseif ( ($locationid >= 67000000) && ($locationid < 68000000) )
				$newlocid = $locationid - 6000000;
			else
				$newlocid = $locationid;
				
			$item['locationID'] = $newlocid;
			$item['typeID'] = $row['typeID'];
			$item['quantity'] = $row['quantity'];
			$item['flag'] = $row['flag'];
			$item['singleton'] = $row['singleton'];
			
			$this->assets_[] = $item;
			unset($item);
				
			// handle asset contained within
			$containeritemid = $row['itemID'];
			$containerlocationid = $newlocid;
			if ($row->rowset->row)
				$this->item($row->rowset, $containeritemid, $containerlocationid);
		}
	}
}
?>