<?php
/**
 * Eve-Online API Trawler
 *
 */

class CharacterAPI
{
	function CharacterAPI( $userID, $apiKey, $charID )
    {
		$this->userID_ = $userID;
		$this->charID_ = $charID;
		$this->apiKey_ = $apiKey;
        $this->apiString_ = array( "userID" => $userID, "apiKey" => $apiKey, "characterID" => $charID );
		
		$this->CacheTime_ = ApiCache::get($this->charID_ . "_charsheet");
		$this->CurrentTime_ = ApiCurrent::get($this->charID_ . "_charsheet");
		
		// define arrays
		$this->skills_ = array();
		$this->attribs_ = array();
    }
	
	function fetch()
	{
		$baseURL = "http://api.eve-online.com/char/CharacterSheet.xml.aspx?";
		
		if ($this->CacheTime_ == "")
    	{
        	$this->CacheTime_ = "2005-01-01 00:00:00"; // fake date to ensure that it runs first time.
    	}
		
		if (is_file(getcwd()."/cache/" . $this->charID_ . "_charsheet.xml"))
			$cacheexists = true;
		else
			$cacheexists = false;
		
		if ((strtotime(gmdate("M d Y H:i:s")) - strtotime($this->CacheTime_) > 0) || !$cacheexists )
        {
            // Load new XML
			$xmlString = @file_get_contents( $baseURL . http_build_query( $this->apiString_ ) );
			$this->isCached = false;
			
        	if(!isset($xmlString) || $xmlString === false)
				$this->error_ = "API Website not responding.";
		} else {
			// load cached XML
			$xmlString = @file_get_contents( "cache/" . $this->charID_ . "_charsheet.xml" );
			$this->isCached = true;
		}
        $xml = simplexml_load_string( $xmlString );
		
        if( isset($xml->error) )
        {
			$this->error_ = $xml->error;
            $xml = @simplexml_load_file( "cache/" . $this->charID_ . "_charsheet.xml" );
			$this->isCached = true;
        } else {
            file_put_contents( "cache/" . $this->charID_  . "_charsheet.xml", $xmlString );
        }
		
		// Set Cached Time
		if ($xml->cachedUntil)
		{
			$this->CacheTime_ = $xml->cachedUntil;
			$this->CurrentTime_ = $xml->currentTime;
			ApiCache::set($this->charID_ . "_charsheet", $this->CacheTime_);
			ApiCurrent::set($this->charID_ . "_charsheet", $this->CurrentTime_);
		}
		
		if ($this->isCached)
		{
			$this->output_ = "using cached file from: " . $this->CurrentTime_ . " and is cached until: " . $this->CacheTime_;
		} else {
			$this->output_ = "received new XML at: " . $this->CurrentTime_;
		}
		
		if ( !$xml->result->rowset->row )
			return false;
		
		// collect char info
		$this->info_['characterID'] = $xml->result->characterID;
		$this->info_['name'] = $xml->result->name;
		$this->info_['race'] = $xml->result->race;
		$this->info_['bloodLine'] = $xml->result->bloodLine;
		$this->info_['gender'] = $xml->result->gender;
		$this->info_['corporationName'] = $xml->result->corporationName;
		$this->info_['corporationID'] = $xml->result->corporationID;
		$this->info_['cloneName'] = $xml->result->cloneName;
		$this->info_['cloneSkillPoints'] = $xml->result->cloneSkillPoints;
		$this->info_['balance'] = $xml->result->balance;
		
		// collect attribute enhancers
		$this->info_['intelligenceImplant'] = $xml->result->attributeEnhancers->intelligenceBonus->augmentatorName;
		$this->info_['intelligenceBonus'] = $xml->result->attributeEnhancers->intelligenceBonus->augmentatorValue;
		$this->info_['memoryImplant'] = $xml->result->attributeEnhancers->memoryBonus->augmentatorName;
		$this->info_['memoryBonus'] = $xml->result->attributeEnhancers->memoryBonus->augmentatorValue;
		$this->info_['charismaImplant'] = $xml->result->attributeEnhancers->charismaBonus->augmentatorName;
		$this->info_['charismaBonus'] = $xml->result->attributeEnhancers->charismaBonus->augmentatorValue;
		$this->info_['perceptionImplant'] = $xml->result->attributeEnhancers->perceptionBonus->augmentatorName;
		$this->info_['perceptionBonus'] = $xml->result->attributeEnhancers->perceptionBonus->augmentatorValue;
		$this->info_['willpowerImplant'] = $xml->result->attributeEnhancers->willpowerBonus->augmentatorName;
		$this->info_['willpowerBonus'] = $xml->result->attributeEnhancers->willpowerBonus->augmentatorValue;
		
		// collect attributes
		$this->info_['intelligence'] = $xml->result->attributes->intelligence;
		$this->info_['memory'] = $xml->result->attributes->memory;
		$this->info_['charisma'] = $xml->result->attributes->charisma;
		$this->info_['perception'] = $xml->result->attributes->perception;
		$this->info_['willpower'] = $xml->result->attributes->willpower;
		
		// collect data from rows
		foreach( $xml->result->rowset as $rowset )
        {
			//collect skills info
			if ($rowset['name'] == "skills")
			{
				foreach ($rowset->row as $row)
				{
					$SkillsArray[] = $row;
				}
			}
			
			//collect certificates info
			if ($rowset['name'] == "certificates")
			{
				foreach ($rowset->row as $row)
				{
					$CertificatessArray[] = $row;
				}
			}
			
			//collect roles info
			if ($rowset['name'] == "corporationRoles")
			{
				foreach ($rowset->row as $row)
				{
					$corporationRolesArray[] = $row;
				}
			}
			if ($rowset['name'] == "corporationRolesAtHQ")
			{
				foreach ($rowset->row as $row)
				{
					$corporationRolesAtHQArray[] = $row;
				}
			}
			if ($rowset['name'] == "corporationRolesAtBase")
			{
				foreach ($rowset->row as $row)
				{
					$corporationRolesAtBaseArray[] = $row;
				}
			}
			if ($rowset['name'] == "corporationRolesAtOther")
			{
				foreach ($rowset->row as $row)
				{
					$corporationRolesAtOtherArray[] = $row;
				}
			}
			
			//collect titles info
			if ($rowset['name'] == "corporationTitles")
			{
				foreach ($rowset->row as $row)
				{
					$corporationTitlesArray[] = $row;
				}
			}
			
			$this->skills_ = $SkillsArray;
			$this->certificates_ = $CertificatessArray;
			$this->roles_['corporationRoles'] = $corporationRolesArray;
			$this->roles_['corporationRolesAtHQ'] = $corporationRolesAtHQArray;
			$this->roles_['corporationRolesAtBase'] = $corporationRolesAtBaseArray;
			$this->roles_['corporationRolesAtOther'] = $corporationRolesAtOtherArray;
			$this->titles_ = $corporationTitlesArray;
		}
		
		return;
	}
}
?>