<?php
/**
 * Eve-Online API Trawler
 *
 */

class CorporationAPI
{
	function CorporationAPI( $userID, $apiKey, $charID, $corpID )
    {
		$this->userID_ = $userID;
		$this->charID_ = $charID;
		$this->apiKey_ = $apiKey;
		$this->corpID_ = $corpID;
		
        $this->apiString_ = array( "userID" => $userID, "apiKey" => $apiKey, "characterID" => $charID );
		
		$this->CacheTime_ = ApiCache::get($this->corpID_ . "_corporationsheet");
		$this->CurrentTime_ = ApiCurrent::get($this->corpID_ . "_corporationsheet");
		
		// define arrays
		$this->divisions_ = array();
		$this->walletDivisions_ = array();
    }
	
	function fetch()
	{
		$baseURL = "http://api.eve-online.com/corp/CorporationSheet.xml.aspx?";
		
		if ($this->CacheTime_ == "")
    	{
        	$this->CacheTime_ = "2005-01-01 00:00:00"; // fake date to ensure that it runs first time.
    	}
		
		if (is_file(getcwd()."/cache/" . $this->corpID_ . "_corporationsheet.xml"))
			$cacheexists = true;
		else
			$cacheexists = false;
		
		if ((strtotime(gmdate("M d Y H:i:s")) - strtotime($this->CacheTime_) > 0) || !$cacheexists )
        {
            // Load new XML
			$xmlString = @file_get_contents( $baseURL . http_build_query( $this->apiString_ ) );
			$this->isCached = false;
			
        	if(!isset($xmlString) || $xmlString === false)
				$this->error_ = "API Website not responding.";
		} else {
			// load cached XML
			$xmlString = @file_get_contents( "cache/" . $this->corpID_ . "_corporationsheet.xml" );
			$this->isCached = true;
		}
        $xml = simplexml_load_string( $xmlString );
		
        if( isset($xml->error) )
        {
			$this->error_ = $xml->error;
            $xml = @simplexml_load_file( "cache/" . $this->corpID_ . "_corporationsheet.xml" );
			$this->isCached = true;
        } else {
            file_put_contents( "cache/" . $this->corpID_  . "_corporationsheet.xml", $xmlString );
        }
		
		// Set Cached Time
		if ($xml->cachedUntil)
		{
			$this->CacheTime_ = $xml->cachedUntil;
			$this->CurrentTime_ = $xml->currentTime;
			ApiCache::set($this->corpID_ . "_corporationsheet", $this->CacheTime_);
			ApiCurrent::set($this->corpID_ . "_corporationsheet", $this->CurrentTime_);
		}
		
		if ($this->isCached)
		{
			$this->output_ = "using cached file from: " . $this->CurrentTime_ . " and is cached until: " . $this->CacheTime_;
		} else {
			$this->output_ = "received new XML at: " . $this->CurrentTime_;
		}
		
		if ( !$xml->result->rowset->row )
			return false;
		
		// collect corp info
		$this->info_['corporationID'] = $xml->result->corporationID;
		$this->info_['corporationName'] = $xml->result->corporationName;
		$this->info_['ticker'] = $xml->result->ticker;
		$this->info_['ceoID'] = $xml->result->ceoID;
		$this->info_['ceoName'] = $xml->result->ceoName;
		$this->info_['stationID'] = $xml->result->stationID;
		$this->info_['stationName'] = $xml->result->stationName;
		$this->info_['description'] = $xml->result->description;
		$this->info_['url'] = $xml->result->url;
		$this->info_['allianceID'] = $xml->result->allianceID;
		$this->info_['allianceName'] = $xml->result->allianceName;
		$this->info_['taxRate'] = $xml->result->taxRate;
		$this->info_['memberCount'] = $xml->result->memberCount;
		$this->info_['memberLimit'] = $xml->result->memberLimit;
		$this->info_['shares'] = $xml->result->shares;
			
		// collect data from rows
		foreach( $xml->result->rowset as $rowset )
        {
			//collect hangar division names
			if ($rowset['name'] == "divisions")
			{
				foreach ($rowset->row as $row)
				{
					$divisions[] = $row;
				}
			}
			
			//collect wallet division names
			if ($rowset['name'] == "walletDivisions")
			{
				foreach ($rowset->row as $row)
				{
					$walletDivisions[] = $row;
				}
			}

			$this->divisions_ = $divisions;
			$this->walletDivisions_ = $walletDivisions;
		}
		return;
	}
}
?>