<?php
/**
 * Eve-Online API Trawler
 *
 */

class StandingsAPI
{
	function StandingsAPI( $userID, $apiKey, $charID, $corpID = 0 )
    {
		$this->userID_ = $userID;
		$this->charID_ = $charID;
		$this->apiKey_ = $apiKey;
		$this->corpID_ = $corpID;
		
		$this->apiString_ = array( "userID" => $this->userID_, "apiKey" => $this->apiKey_, "characterID" => $this->charID_ );
		$this->orders_ = array();
		
		if ($this->corpID_ != 0)
		{
			$this->CacheTime_ = ApiCache::get($this->corpID_ . "_corpstandings");
			$this->CurrentTime_ = ApiCurrent::get($this->corpID_ . "_corpstandings");
		} else {
			$this->CacheTime_ = ApiCache::get($this->charID_ . "_standings");
			$this->CurrentTime_ = ApiCurrent::get($this->charID_ . "_standings");
		}
    }
	
	function fetch()
	{
		if ($this->corpID_ != 0)
		{
			$baseURL = "http://api.eve-online.com/corp/Standings.xml.aspx?";
			$fname = "cache/" . $this->corpID_ . "_corpstandings.xml";
		} else {
			$baseURL = "http://api.eve-online.com/char/Standings.xml.aspx?";
			$fname = "cache/" . $this->charID_ . "_standings.xml";
		}

		if ($this->CacheTime_ == "")
    	{
        	$this->CacheTime_ = "2005-01-01 00:00:00"; // fake date to ensure that it runs first time.
    	}
		
		if (is_file(getcwd()."/".$fname))
			$cacheexists = true;
		else
			$cacheexists = false;
		
		if ((strtotime(gmdate("M d Y H:i:s")) - strtotime($this->CacheTime_) > 0) || !$cacheexists )
        {
            // Load new XML
			$xmlString = @file_get_contents( $baseURL . http_build_query( $this->apiString_ ) );
			$this->isCached = false;
			
			if(!isset($xmlString) || $xmlString === false)
				$this->error_ = "API Website not responding.";
		} else {
			// load cached XML
			$xmlString = @file_get_contents( $fname );
			$this->isCached = true;
		}
        $xml = simplexml_load_string( $xmlString );
        
        if( isset($xml->error) )
        {
			$this->error_ = $xml->error;
			// suppress errors/warnings incase file does not exist
            $xml = @simplexml_load_file( $fname );
			$this->isCached = true;
        } else {
            file_put_contents( $fname, $xmlString );
        }
		
		// Set Cached Time
		if ($xml->cachedUntil)
		{
			$this->CacheTime_ = $xml->cachedUntil;
			$this->CurrentTime_ = $xml->currentTime;
			
			if ($this->corpID_ != 0)
			{
				ApiCache::set($this->corpID_ . "_corpstandings", $this->CacheTime_);
    			ApiCurrent::set($this->corpID_ . "_corpstandings", $this->CurrentTime_);
			} else {
				ApiCache::set($this->charID_ . "_standings", $this->CacheTime_);
				ApiCurrent::set($this->charID_ . "_standings", $this->CurrentTime_);
			}
		}
		
		if ($this->isCached)
		{
			$this->output_ = "using cached file from: " . $this->CurrentTime_ . " and is cached until: " . $this->CacheTime_;
		} else {
			$this->output_ = "received new XML at: " . $this->CurrentTime_;
		}
		
		if( !$xml->result )
			return false;
		
		// collect data from corp standings
		if ($xml->result->corporationStandings->standingsTo)
		{
			$CorporationStandingsTo = $xml->result->corporationStandings->standingsTo;
			foreach( $CorporationStandingsTo->rowset as $corprowset )
			{
				$type = "corp";
				
				//collect corporation->characters standings
				if ($corprowset['name'] == "characters")
				{
					$subtype = "char";
					foreach ( $corprowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
						
						$temparray[] = $temp;
						unset($temp);
					}
				}
				
				//collect corporation->corporations standings
				if ($corprowset['name'] == "corporations")
				{
					$subtype = "corp";
					foreach ( $corprowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
						
						$temparray[] = $temp;
						unset($temp);
					}
				}
				
				//collect corporation->alliances standings
				if ($corprowset['name'] == "alliances")
				{
					$subtype = "alliance";
					foreach ( $corprowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
						
						$temparray[] = $temp;
						unset($temp);
					}
				}
			}
		}
		
		// collect data from alliance standings
		if ($xml->result->allianceStandings->standingsTo)
		{
			$AllianceStandingsTo = $xml->result->allianceStandings->standingsTo;
			foreach( $AllianceStandingsTo->rowset as $alliancerowset )
			{
				$type = "alliance";
				
				//collect corporation->corporations standings
				if ($alliancerowset['name'] == "corporations")
				{
					$subtype = "corp";
					foreach ( $alliancerowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
						
						$temparray[] = $temp;
						unset($temp);
					}
				}
				
				//collect corporation->alliances standings
				if ($alliancerowset['name'] == "alliances")
				{
					$subtype = "alliance";
					foreach ( $alliancerowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
						
						$temparray[] = $temp;
						unset($temp);
					}
				}
			}
		}
		
		// collect data from character standings
		if ($xml->result->standingsTo)
		{
			$charStandingsTo = $xml->result->standingsTo;
			foreach( $charStandingsTo->rowset as $charrowset )
        	{
				$type = "char";
			
				//collect corporation->characters standings
				if ($charrowset['name'] == "characters")
				{
					$subtype = "char";
					foreach ( $charrowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
					
						$temparray[] = $temp;
						unset($temp);
					}
				}
			
				//collect corporation->corporations standings
				if ($charrowset['name'] == "corporations")
				{
					$subtype = "corp";
					foreach ( $charrowset->row as $row)
					{
						$temp['type'] = $type;
						$temp['subtype'] = $subtype;
						$temp['toID'] = $row['toID'];
						$temp['toName'] = $row['toName'];
						$temp['standing'] = $row['standing'];
						
						$temparray[] = $temp;
						unset($temp);
					}
				}
			}
		}
		
		return $temparray;
	}
}
?>