<?php
/**
 * Eve-Online API Trawler
 *
 */
require_once('includes/class.api.idtoname.php');

class itemIDDB
{
    function itemIDDB()
    {
        itemIDDB::init();
    }

    function init()
    {
        global $ItemID_init;

        if ($ItemID_init)
        {
            return;
        }

        $db = new DBQuery(true);
		$db->execute("CREATE TABLE IF NOT EXISTS `eve_itemid` (
 			 `itemID` INT UNSIGNED NOT NULL,
  			 `itemName` varchar(64) NULL,
  			 PRIMARY KEY  (`itemID`)
			 )");
        $db->execute('select * from eve_itemid');
        $itemIDDB = &itemIDDB::_getCache();
        while ($row = $db->getRow())
        {
            if (substr($row['itemName'], 0, 2) == 'a:')
            {
                $row['itemName'] = unserialize($row['itemName']);
            }
            $itemIDDB[$row['itemID']] = $row['itemName'];
        }
        $ItemID_init = true;
    }

	function &_getCache()
    {
    	static $cache;

    	if (!isset($cache))
        {
    	    $cache = array();
    	}
    	return $cache;
    }
	
    function put($id, $data)
    {
    	$cache = &itemIDDB::_getCache();
    	$cache[$id] = $data;
    }

    function del($id)
    {
    	$cache = &itemIDDB::_getCache();
    	if (isset($cache[$id]))
    	{
    	    unset($cache[$id]);
    	}

        $qry = new DBQuery();
        $qry->execute("delete from eve_itemid where itemID = '".$id."'");
    }

    function set($id, $value)
    {
    	$cache = &itemIDDB::_getCache();

		if($id == 0)
			return;
			
    	if (isset($cache[$id]))
    	{
			// only update the database when the old value differs
    	    if ($cache[$id] === $value)
    	    {
    	        return;
    	    }
			
			// If Cached key has been marked as unresolved, do not allow it to be set back to NULL
			if ($cache[$id] === "<unresolved ID>")
			{
				return;
			}
			
			// If Cached key has already been resolved do not allow it to be set back to NULL
			if ( ($cache[$id] !== NULL) && ($value === NULL) )
			{
				return;
			}
    	}

    	if (is_array($value))
    	{
    	    $cache[$id] = $value;
    	    $value = serialize($value);
    	}
    	else
    	{
    	    $cache[$id] = stripslashes($value);
        }
        $value = addslashes($value);

        $qry = new DBQuery();
        $qry->execute("select itemName from eve_itemid
                       where itemID = '".$id."'");
        if ($qry->recordCount())
        {
			if ($value == NULL)
				$sql = "update eve_itemid set itemName = NULL
                    where itemID = '".$id."'";
			else
            	$sql = "update eve_itemid set itemName = '".slashfix($value)."'
                    where itemID = '".$id."'";
        }
        else
        {
			if ($value == NULL)
				$sql = "insert into eve_itemid values ('".$id."',NULL)";
			else
	            $sql = "insert into eve_itemid values ('".$id."','".slashfix($value)."')";
        }
        $qry->execute($sql);
    }

    function &get($id)
    {
    	$cache = &itemIDDB::_getCache();

    	if (!isset($cache[$id]))
    	{
    	    return itemIDDB::defaultval($id);
    	}
    	return stripslashes($cache[$id]);
    }

	function &getnumerical($id)
    {
    	$cache = &itemIDDB::_getCache();

    	if (!isset($cache[$id]))
    	{
    	    return itemIDDB::defaultval($id);
    	}
    	return $cache[$id];
    }
    function defaultval($id)
    {
        // add important upgrade configs here, they will return the default if not set
        // they will be shown as set but take no space in the database
        //$defaults = array('summarytable_rowcount' => 8);
		//$defaults = array('killcount' => 50);
		
        if (!isset($defaults[$id]))
        {
            return null;
        }
        return $defaults[$id];
    }
	
	function resolvevalues()
	{
		// This function collects an array of upto 100 NULL value IDs then resolves the ID's to names and updates the DB
		// It repeats until all NULL IDs are resolved.
		$resolveditems = 0;
		$unresolveditems = 0;
		do {
			unset($resolvearray);
			unset($idstring);
			
			$resolvearray = array();
			
			$qry = new DBQuery();
        	$qry->execute("SELECT * 
							FROM `eve_itemid` 
							WHERE `itemName` IS NULL 
							LIMIT 0 , 100"); 			// The limit here determines how many IDs are sent per page
														// I don't know how many the page can handle so have settled for 100
														
        	if ($qry->recordCount())
        	{
				while ($row = $qry->getRow())
        		{
            		$resolvearray[] = $row['itemID'];
        		}
				
				// create string and dispatch to API class
				foreach ($resolvearray as $id)
				{
					if (!isset($idstring))
						$idstring = $id;
					else
						$idstring .= "," . $id;
				}
				
				$myIDtoName = new IDtoName();
				$myReturnArray = $myIDtoName->resolve($idstring);
				
				if ($myReturnArray)
				{
					foreach ($myReturnArray as $return)
					{
						// prevent an endless loop should the name not be resolved (an example would be a closed corp or deleted char)
						// we could attempt to resolve these ids again at a later date by setting all "<unresolved ID>" to NULL
						$name = (string)$return['name'];
						
						if ($name == NULL) 
						{
							$name = "<unresolved ID>";
							$unresolveditems++;	
						} else {
							$resolveditems++;
						}
							
						itemIDDB::set((integer)$return['characterID'], $name);
					}
				}
				echo ".";
				trawlflush();
			}
			
		} while ($qry->recordCount());
		
		if ( ($resolveditems != 0) || ($unresolveditems != 0) )
		{
			$returnstring = number_format((float)$resolveditems,0) . " itemIDs have been resolved";
			if ($unresolveditems > 0)
				$returnstring .= " and " . number_format((float)$unresolveditems,0) . " itemIDs have failed to resolve<br>";
			else
				$returnstring .= "<br>";
		}
		echo "<br>";
		trawlflush();
		return $returnstring;
	}
}
?>
